*****************
Design And Goals
*****************

This project's goals are to map 100% of the ``libssh2`` C API to Python, using Python semantics where appropriate.

Design wise, the library is intentionally a thin wrapper of ``libssh2``, implemented in Cython, in order to have as little overhead and conversely as high performance as possible.

Contributions are most welcome!
